# combo - content management system
# Copyright (C) 2021  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import connection

from uwsgidecorators import spool

from combo.apps.dataviz.models import ChartNgCell
from combo.apps.dataviz.utils import update_available_statistics
from combo.utils import requests


def set_connection(domain):
    from hobo.multitenant.middleware import TenantMiddleware

    tenant = TenantMiddleware.get_tenant_by_hostname(domain)
    connection.set_tenant(tenant)


@spool
def refresh_statistics_list(args):
    if args.get('domain'):
        # multitenant installation
        set_connection(args['domain'])

    update_available_statistics()


@spool
def refresh_statistics_data(args):
    if args.get('domain'):
        # multitenant installation
        set_connection(args['domain'])

    cell = ChartNgCell.objects.get(pk=args['cell_pk'])
    cell.get_statistic_data(invalidate_cache=True)
